@@ -2,13 +2,14 @@ import buble from 'rollup-plugin-buble';
 import json from 'rollup-plugin-json';
 import resolve from 'rollup-plugin-node-resolve';
 import commonjs from 'rollup-plugin-commonjs';
+import pkg from './package.json';
 
 const ensureArray = maybeArr => Array.isArray(maybeArr) ? maybeArr : [maybeArr];
 
 const createConfig = (opts) => {
 	opts = opts || {};
 	const browser = opts.browser || false;
-	const external = opts.external || ['acorn', 'magic-string'];
+	const external = opts.external || Object.keys(pkg.dependencies || {});
 	const output = ensureArray(opts.output);
 
 	return {
@@ -20,11 +21,13 @@ const createConfig = (opts) => {
 		external: external,
 		plugins: [
 			json(),
-			commonjs(),
+			commonjs({ extensions: ['.js', '.mjs'] }),
 			buble({
 				target: !browser ? { node: 4 } : null,
 				include: [
 					'src/**',
+					// For unpkg build
+					'node_modules/acorn-jsx/**',
 					'node_modules/regexpu-core/**',
 					'node_modules/unicode-match-property-ecmascript/**',
 					'node_modules/unicode-match-property-value-ecmascript/**',
