@@ -117,7 +117,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var Foo = (function (Bar) {
+			var Foo = /*@__PURE__*/(function (Bar) {
 				function Foo () {
 					Bar.apply(this, arguments);
 				}
@@ -150,7 +150,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var Foo = (function (Bar) {
+			var Foo = /*@__PURE__*/(function (Bar) {
 				function Foo ( x ) {
 					Bar.call( this, x );
 					this.y = 'z';
@@ -188,7 +188,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var Foo = (function (Bar) {
+			var Foo = /*@__PURE__*/(function (Bar) {
 				function Foo () {
 					Bar.apply(this, arguments);
 				}
@@ -254,7 +254,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var Foo = (function (Bar) {
+			var Foo = /*@__PURE__*/(function (Bar) {
 				function Foo () {
 					Bar.apply(this, arguments);
 				}
@@ -283,7 +283,7 @@ module.exports = [
 			new Foo().bar();`,
 
 		output: `
-			var Foo = (function (Bar) {
+			var Foo = /*@__PURE__*/(function (Bar) {
 				function Foo () {
 					Bar.apply(this, arguments);
 				}
@@ -316,7 +316,7 @@ module.exports = [
 			var Foo = class {};`,
 
 		output: `
-			var Foo = (function () {
+			var Foo = /*@__PURE__*/(function () {
 				function Foo () {}
 
 				return Foo;
@@ -334,7 +334,7 @@ module.exports = [
 			};`,
 
 		output: `
-			var Foo = (function () {
+			var Foo = /*@__PURE__*/(function () {
 				function Foo ( x ) {
 					this.x = x;
 				}
@@ -355,7 +355,7 @@ module.exports = [
 			};`,
 
 		output: `
-			var Foo = (function () {
+			var Foo = /*@__PURE__*/(function () {
 				function Foo () {}
 
 				Foo.prototype.bar = function bar ( x ) {
@@ -380,7 +380,7 @@ module.exports = [
 		output: `
 			var q = {};
 
-			q.a = (function () {
+			q.a = /*@__PURE__*/(function () {
 				function a () {}
 
 				a.prototype.c = function c () {};
@@ -515,7 +515,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var Circle = (function (Shape) {
+			var Circle = /*@__PURE__*/(function (Shape) {
 				function Circle ( radius ) {
 					Shape.call(this);
 					this.radius = radius;
@@ -579,13 +579,13 @@ module.exports = [
 			}`,
 
 		output: `
-			var q = {a: (function () {
+			var q = {a: /*@__PURE__*/(function () {
 				function anonymous () {}
 
 				return anonymous;
 			}())};
 
-			var b = (function (superclass) {
+			var b = /*@__PURE__*/(function (superclass) {
 				function b () {
 					superclass.apply(this, arguments);
 				}
@@ -611,13 +611,13 @@ module.exports = [
 			};`,
 
 		output: `
-			var q = {a: (function () {
+			var q = {a: /*@__PURE__*/(function () {
 				function anonymous () {}
 
 				return anonymous;
 			}())};
 
-			var b = (function (superclass) {
+			var b = /*@__PURE__*/(function (superclass) {
 				function b () {
 					superclass.apply(this, arguments);
 				}
@@ -643,7 +643,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var b = (function (superclass) {
+			var b = /*@__PURE__*/(function (superclass) {
 				function b() {
 					superclass.call(this);
 				}
@@ -667,7 +667,7 @@ module.exports = [
 			};`,
 
 		output: `
-			SubClass = (function (SuperClass) {
+			SubClass = /*@__PURE__*/(function (SuperClass) {
 				function SubClass() {
 					SuperClass.call(this);
 				}
@@ -739,7 +739,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var Foo = (function (Bar) {
+			var Foo = /*@__PURE__*/(function (Bar) {
 				function Foo () {
 					Bar.apply(this, arguments);
 				}
@@ -781,7 +781,7 @@ module.exports = [
 
 			A.prototype.x = function x (){};
 
-			var B = (function () {
+			var B = /*@__PURE__*/(function () {
 				function B () {}
 
 				B.prototype.x = function x (){};
@@ -789,7 +789,7 @@ module.exports = [
 				return B;
 			}());
 
-			var C = (function (D) {
+			var C = /*@__PURE__*/(function (D) {
 				function C () {
 					D.apply(this, arguments);
 				}
@@ -803,7 +803,7 @@ module.exports = [
 				return C;
 			}(D));
 
-			var E = (function (F) {
+			var E = /*@__PURE__*/(function (F) {
 				function E () {
 					F.apply(this, arguments);
 				}
@@ -905,7 +905,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var Foo = (function (Bar) {
+			var Foo = /*@__PURE__*/(function (Bar) {
 				function Foo ( options, ref ) {
 					var this$1 = this;
 					var a2 = ref.a2;
@@ -947,7 +947,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var SubClass = (function (SuperClass) {
+			var SubClass = /*@__PURE__*/(function (SuperClass) {
 				function SubClass() {
 					var args = [], len = arguments.length;
 					while ( len-- ) args[ len ] = arguments[ len ];
@@ -974,7 +974,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var SubClass = (function (SuperClass) {
+			var SubClass = /*@__PURE__*/(function (SuperClass) {
 				function SubClass() {
 					var args = [], len = arguments.length;
 					while ( len-- ) args[ len ] = arguments[ len ];
@@ -1101,7 +1101,7 @@ module.exports = [
 			}`,
 
 		output: `
-			var A = (function (B) {
+			var A = /*@__PURE__*/(function (B) {
 				function A () {
 					var this$1 = this;
 
@@ -1157,7 +1157,7 @@ module.exports = [
 
 			B[.000004] = function (){};
 			B[x] = function (){};
-			B [x-y] = function (){};
+			B[x-y] = function (){};
 			B[("Static computed " + name)] = function (){};
 		`
 	},
@@ -1226,6 +1226,28 @@ module.exports = [
 			X.prototype.foo = function foo$1 () { return foo };
 			X.prototype.bar = function bar () {};
 		`
+	},
+
+	{
+		description: "transpiles class with super class in arrow function (#150)",
+
+		input: `
+			const f = (b) => class a extends b {};
+		`,
+
+		output: `
+			var f = function (b) { return /*@__PURE__*/(function (b) {
+					function a () {
+						b.apply(this, arguments);
+					}if ( b ) a.__proto__ = b;
+					a.prototype = Object.create( b && b.prototype );
+					a.prototype.constructor = a;
+
+					
+
+					return a;
+				}(b)); };
+		`
 	}
 
 	// TODO more tests. e.g. getters and setters.
